@@ -1,7 +1,7 @@
 """Communicates with databases using repository pattern and service patterns"""
 
 
-__version__ = '0.23.0'
+__version__ = '0.24.0'
 
 from dbdaora.cache import CacheType, TTLDaoraCache
 from dbdaora.circuitbreaker import AsyncCircuitBreaker
@@ -17,9 +17,10 @@ from dbdaora.geospatial.repositories import GeoSpatialRepository
 from dbdaora.geospatial.service import GeoSpatialService
 from dbdaora.hash.factory import make_service as make_hash_service
 from dbdaora.hash.query import HashQuery, HashQueryMany
-from dbdaora.hash.repositories import HashData, HashRepository
+from dbdaora.hash.repositories import HashData, HashEntity, HashRepository
 from dbdaora.hash.service import HashService
 from dbdaora.hashring import HashRing
+from dbdaora.keys import FallbackKey
 from dbdaora.query import Query, QueryMany
 from dbdaora.repository import MemoryRepository
 from dbdaora.service import CACHE_ALREADY_NOT_FOUND, Service
@@ -35,11 +36,11 @@ from dbdaora.sorted_set.query import SortedSetQuery
 from dbdaora.sorted_set.repositories import SortedSetRepository
 
 
+from dbdaora.boolean.factory import (  # noqa isort:skip
+    make_service as make_boolean_service,
+)
 from dbdaora.boolean.repositories import BooleanRepository  # noqa isort:skip
 from dbdaora.boolean.service import BooleanService  # noqa isort:skip
-from dbdaora.boolean.repositories.datastore import (  # noqa isort:skip
-    DatastoreBooleanRepository,
-)
 
 try:
     from dbdaora.data_sources.fallback.datastore import (
@@ -56,6 +57,9 @@ try:
         DatastoreGeoSpatialRepository,
     )
     from dbdaora.sorted_set.service.datastore import DatastoreSortedSetService
+    from dbdaora.boolean.repositories.datastore import (
+        DatastoreBooleanRepository,
+    )
 except ImportError:
     DatastoreDataSource = None  # type: ignore
     KindKeyDatastoreDataSource = None  # type: ignore
@@ -65,6 +69,7 @@ except ImportError:
     DatastoreGeoSpatialService = None  # type: ignore
     DatastoreGeoSpatialRepository = None  # type: ignore
     DatastoreSortedSetService = None  # type: ignore
+    DatastoreBooleanRepository = None  # type: ignore
 
 try:
     from dbdaora.data_sources.memory.aioredis import (
@@ -143,6 +148,9 @@ __all__ = [
     'GeoSpatialData',
     'make_sorted_set_service',
     'CACHE_ALREADY_NOT_FOUND',
+    'FallbackKey',
+    'HashEntity',
+    'make_boolean_service',
 ]
 
 if AioRedisDataSource:
@@ -204,3 +212,6 @@ if MongodbSortedSetRepository:
 
 if MongoSortedSetService:
     __all__.append('MongoSortedSetService')
+
+if DatastoreBooleanRepository:
+    __all__.append('DatastoreBooleanRepository')
