@@ -20,12 +20,20 @@ from dbdaora.hashring import HashRing
 from . import GeoRadiusOutput, MemoryDataSource, MemoryMultiExec, RangeOutput
 
 
+try:
+    import newrelic.agent
+except ImportError:
+    newrelic = None  # type: ignore
+
+
 class AioRedisDataSource(Redis, MemoryDataSource):
-    ...
+    geopoint_cls: ClassVar[Type[GeoPoint]] = GeoPoint  # type: ignore
+    geomember_cls: ClassVar[Type[GeoMember]] = GeoMember  # type: ignore
 
 
 class AioRedisMultiExec(MultiExec):
-    ...
+    geopoint_cls: ClassVar[Type[GeoPoint]] = GeoPoint
+    geomember_cls: ClassVar[Type[GeoMember]] = GeoMember
 
 
 @dataclasses.dataclass
@@ -35,6 +43,8 @@ class ShardsAioRedisMultiExec(MemoryMultiExec):
     clients_to_execute: Set[AioRedisMultiExec] = dataclasses.field(
         default_factory=set
     )
+    geopoint_cls: ClassVar[Type[GeoPoint]] = GeoPoint
+    geomember_cls: ClassVar[Type[GeoMember]] = GeoMember
 
     def get_client(self, key: str) -> AioRedisMultiExec:
         return self.hashring.get_node(key)
@@ -230,9 +240,10 @@ async def make(
     *uris: str,
     hashring_cls: Type[HashRing[AioRedisDataSource]] = HashRing,
     hashring_nodes_size: Optional[int] = None,
-    commands_factory: Type[
+    sharded_commands_factory: Type[
         ShardsAioRedisDataSource
     ] = ShardsAioRedisDataSource,
+    single_commands_factory: Type[AioRedisDataSource] = AioRedisDataSource,
 ) -> Union[Redis, ShardsAioRedisDataSource]:
     if len(uris) == 0:
         uris = ['redis://']  # type: ignore
@@ -240,14 +251,136 @@ async def make(
     if len(uris) > 1:
         clients: Sequence[AioRedisDataSource] = [
             await create_redis_pool(  # type: ignore
-                uri, commands_factory=AioRedisDataSource
+                uri, commands_factory=single_commands_factory
             )
             for uri in uris
         ]
         hashring = hashring_cls(clients, hashring_nodes_size)
-        return commands_factory(hashring)
+        return sharded_commands_factory(hashring)
 
     else:
         return await create_redis_pool(
-            uris[0], commands_factory=AioRedisDataSource
+            uris[0], commands_factory=single_commands_factory
         )
+
+
+if newrelic is not None:
+    # KEY COMMANDS
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'set',
+        product='Redis',
+        target=None,
+        operation='set',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'get',
+        product='Redis',
+        target=None,
+        operation='get',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'expire',
+        product='Redis',
+        target=None,
+        operation='expire',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'delete',
+        product='Redis',
+        target=None,
+        operation='delete',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'exists',
+        product='Redis',
+        target=None,
+        operation='exists',
+    )
+
+    # HASH COMMANDS
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'hmset',
+        product='Redis',
+        target=None,
+        operation='hmset',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'hgetall',
+        product='Redis',
+        target=None,
+        operation='hgetall',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'hmget',
+        product='Redis',
+        target=None,
+        operation='hmget',
+    )
+
+    # SORTED SET COMMANDS
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zadd',
+        product='Redis',
+        target=None,
+        operation='zadd',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zrange',
+        product='Redis',
+        target=None,
+        operation='zrange',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zrangebyscore',
+        product='Redis',
+        target=None,
+        operation='zrangebyscore',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zrevrange',
+        product='Redis',
+        target=None,
+        operation='zrevrange',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zrevrangebyscore',
+        product='Redis',
+        target=None,
+        operation='zrevrangebyscore',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'zcard',
+        product='Redis',
+        target=None,
+        operation='zcard',
+    )
+
+    # GEOSPATIAL COMMANDS
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'geoadd',
+        product='Redis',
+        target=None,
+        operation='geoadd',
+    )
+    newrelic.agent.wrap_datastore_trace(
+        AioRedisDataSource,
+        'georadius',
+        product='Redis',
+        target=None,
+        operation='georadius',
+    )
