@@ -1,51 +1,13 @@
-import asyncio
 import dataclasses
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import Any, Dict, Optional, Sequence, Union
 
-from . import MemoryDataSource, MemoryMultiExec, RangeOutput
-
-
-@dataclasses.dataclass
-class DictMultiExec(MemoryMultiExec):
-    client: 'DictMemoryDataSource'
-    futures: List[Any] = dataclasses.field(default_factory=list)
-
-    def delete(self, key: str) -> Any:
-        future = self.client.delete(key)
-        self.futures.append(future)
-        return future
-
-    def hmset(
-        self,
-        key: str,
-        field: Union[str, bytes],
-        value: Union[str, bytes],
-        *pairs: Union[str, bytes],
-    ) -> Any:
-        future = self.client.hmset(key, field, value, *pairs)
-        self.futures.append(future)
-        return future
-
-    def zadd(
-        self, key: str, score: float, member: str, *pairs: Union[float, str]
-    ) -> Any:
-        future = self.client.zadd(key, score, member, *pairs)
-        self.futures.append(future)
-        return future
-
-    async def execute(self, *, return_exceptions: bool = False) -> Any:
-        results = await asyncio.gather(*self.futures)
-        self.futures.clear()
-        return results
+from . import MemoryDataSource, RangeOutput
 
 
 @dataclasses.dataclass
 class DictMemoryDataSource(MemoryDataSource):
     db: Dict[str, Any] = dataclasses.field(default_factory=dict)
 
-    async def get(self, key: str) -> Optional[bytes]:
-        return self.db.get(key)
-
     async def set(self, key: str, data: str) -> None:
         self.db[key] = data.encode()
 
@@ -58,33 +20,18 @@ class DictMemoryDataSource(MemoryDataSource):
     async def exists(self, key: str) -> bool:
         return key in self.db
 
-    async def zrevrange(
-        self, key: str, withscores: bool = False
-    ) -> Optional[RangeOutput]:
-        data: RangeOutput
-
-        if key not in self.db:
-            return None
-
-        if withscores:
-            data = list(self.db[key])
-        else:
-            data = [i[0] for i in self.db[key]]
-
-        data.reverse()
-        return data
-
     async def zrange(
-        self, key: str, withscores: bool = False
+        self,
+        key: str,
+        start: int = 0,
+        stop: int = -1,
+        withscores: bool = False,
     ) -> Optional[RangeOutput]:
         data: Optional[RangeOutput] = self.db.get(key)
 
         if data is None:
             return None
 
-        if withscores:
-            return data
-
         return [i[0] for i in self.db[key]]
 
     async def zadd(
@@ -92,7 +39,13 @@ class DictMemoryDataSource(MemoryDataSource):
     ) -> None:
         data = [score, member] + list(pairs)
         self.db[key] = sorted(
-            [(data[i], data[i - 1]) for i in range(1, len(data), 2)],
+            [
+                (
+                    data[i].encode() if isinstance(data[i], str) else data[i],  # type: ignore
+                    data[i - 1],
+                )
+                for i in range(1, len(data), 2)
+            ],
             key=lambda d: d[1],
         )
 
@@ -116,10 +69,7 @@ class DictMemoryDataSource(MemoryDataSource):
     async def hmget(
         self, key: str, field: Union[str, bytes], *fields: Union[str, bytes]
     ) -> Sequence[Optional[bytes]]:
-        data: Optional[Dict[bytes, Any]] = self.db.get(key)
-
-        if data is None:
-            return [None for i in range(len(fields) + 1)]
+        data: Dict[bytes, Any] = self.db.get(key, {})
 
         return [
             None
@@ -144,6 +94,3 @@ class DictMemoryDataSource(MemoryDataSource):
             )
             for f, d in self.db.get(key, {}).items()
         }
-
-    def multi_exec(self) -> MemoryMultiExec:
-        return DictMultiExec(self)
