@@ -13,6 +13,7 @@ from typing import (  # type: ignore
     Type,
     Union,
     _TypedDictMeta,
+    get_args,
 )
 
 from dbdaora import FallbackDataSource, MemoryDataSource
@@ -32,8 +33,9 @@ from .entity import Entity
 class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
     memory_data_source: MemoryDataSource
     fallback_data_source: FallbackDataSource[FallbackKey]
+    fallback_data_source_key_cls: ClassVar[Type[FallbackKey]]
     expire_time: int
-    entity_cls: ClassVar[Type[Entity]]
+    entity_cls: ClassVar[Optional[Type[Entity]]]
     name: ClassVar[str]
     id_name: ClassVar[str]
     key_attrs: ClassVar[Sequence[str]]
@@ -53,7 +55,34 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
         super().__init_subclass__()
 
         if cls.__name__ not in cls.__skip_cls_validation__:
-            entity_cls = entity_cls or getattr(cls, 'entity_cls', None)
+            has_entity_type = any(
+                [
+                    cls.get_entity_type != base.get_entity_type  # type: ignore
+                    for base in cls.__bases__
+                ]
+            )
+
+            if not has_entity_type:
+                entity_cls = entity_cls or getattr(cls, 'entity_cls', None)
+
+                if not entity_cls:
+                    for base_orig in getattr(cls, '__orig_bases__', tuple()):
+                        base_orig_args = get_args(base_orig)
+
+                        if len(base_orig_args) > 0 and isinstance(
+                            base_orig_args[0], type
+                        ):
+                            has_fallback_data_source_key_cls = hasattr(
+                                cls, 'fallback_data_source_key_cls'
+                            )
+                            if (
+                                has_fallback_data_source_key_cls
+                                and not base_orig_args[0]
+                                is cls.fallback_data_source_key_cls
+                            ) or not has_fallback_data_source_key_cls:
+                                entity_cls = base_orig_args[0]
+                                break
+
             name = name or getattr(cls, 'name', None)
             id_name = id_name or getattr(cls, 'id_name', 'id')
             key_attrs = key_attrs or getattr(cls, 'key_attrs', None)
@@ -68,13 +97,6 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
             if key_attrs is None:
                 key_attrs = (id_name,)
 
-            has_entity_type = any(
-                [
-                    cls.get_entity_type != base.get_entity_type  # type: ignore
-                    for base in cls.__bases__
-                ]
-            )
-
             if not has_entity_type and not entity_cls:
                 raise RequiredClassAttributeError(
                     cls.__name__, 'entity_cls or get_entity_type'
@@ -461,7 +483,7 @@ class MemoryRepository(Generic[Entity, EntityData, FallbackKey]):
         self,
         query: 'Union[BaseQuery[Entity, EntityData, FallbackKey], Entity]',
     ) -> Type[Entity]:
-        return self.entity_cls
+        return self.entity_cls  # type: ignore
 
 
 def task_done_callback(f: Any) -> None:
